@@ -96,7 +96,8 @@ on_treeview2_drag_data_get(GtkWidget * widget,
 			   guint info, guint time, gpointer user_data)
 {
 	gchar *name = "foo_bar";
-	gtk_selection_data_set(data, data->target, 8, name, strlen(name));
+	gtk_selection_data_set(data, data->target, 8, 
+			       (guchar *)name, strlen(name));
 }
 
 // retrieve data
@@ -164,7 +165,8 @@ on_treeview1_drag_data_get(GtkWidget * widget,
 		//g_print("I was dropped on the rootwin\n");
 	} else
 		gtk_selection_data_set(data, data->target, 8,
-				       name_to_drag, strlen(name_to_drag));
+				       (guchar *)name_to_drag, 
+				       strlen(name_to_drag));
 }
 
 GLADE_CB void
