@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_core.h 1125 2005-05-24 18:09:19Z julien $ */
+/* $Id: tilp_core.h 1338 2005-07-06 14:03:53Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -212,8 +212,10 @@ extern "C" {
   int tilp_printl(int level, const char *format, ...);
 
   // GTK+ only (export callbacks for Glade linking at runtime)
-#ifdef __WIN32__
+#if defined(__WIN32__) && !defined(HAVE_FVISIBILITY)
 # define GLADE_CB __declspec(dllexport)
+#elif defined(HAVE_FVISIBILITY)
+# define GLADE_CB __attribute__ ((visibility("default")))
 #else
 # define GLADE_CB
 #endif
