@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_defs.h 366 2004-03-22 18:04:07Z roms $ */
+/* $Id: tilp_defs.h 1125 2005-05-24 18:09:19Z julien $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -54,14 +54,15 @@
 #define LOCK   (!0)
 
 
-/* PCX or XPM image format */
-#define PDF  6
-#define PNG  5
-#define TIFF 4
-#define BMP  3
-#define JPG  2
-#define PCX  1
-#define XPM  0
+/* Image format */
+#define EPS  7   /* Encapsulated PostScript */
+#define PDF  6   /* Portable Document Format */
+#define PNG  5   /* Portable Network Graphics */
+#define TIFF 4   /* Tagged Image File Format */
+#define BMP  3   /* Bitmap */
+#define JPG  2   /* JPEG format */
+#define PCX  1   /* PCX */
+#define XPM  0   /* pixmap */
 
 
 /* Cut or copy selected file */
