@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_plugin.c 735 2004-05-29 08:56:10Z roms $ */
+/* $Id: tilp_plugin.c 902 2005-03-17 08:18:47Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -175,7 +175,8 @@ int tilp_plugins_scan(void)
 #ifdef __WIN32__
 	reg_fn = g_strconcat(inst_paths.base_dir, REG_FILE, NULL);
 #else				/*  */
-	reg_fn = g_strconcat(SYSCONFDIR "/tilp/", REG_FILE, NULL);
+	//reg_fn = g_strconcat(SYSCONFDIR "/tilp/", REG_FILE, NULL);
+	reg_fn = g_strconcat(SHARE_DIR, G_DIR_SEPARATOR_S, REG_FILE, NULL);
 #endif				/*  */
 	//printf("<%s>\n", reg_fn);
 	reg = fopen(reg_fn, "rt");
