@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_rcfile.c 786 2004-09-18 17:32:29Z roms $ */
+/* $Id: tilp_rcfile.c 1125 2005-05-24 18:09:19Z julien $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -436,6 +436,12 @@ void tilp_rcfile_read(void)
 			else if (!strcmp(p, "png"))
 				options.screen_format = PNG;
 
+			else if (!strcmp(p, "pdf"))
+				options.screen_format = PDF;
+
+			else if (!strcmp(p, "eps"))
+				options.screen_format = EPS;
+
 			else
 				stop(l);
 			continue;
@@ -941,6 +947,12 @@ void tilp_rcfile_write(void)
 	case PNG:
 		fprintf(txt, "png\n");
 		break;
+	case PDF:
+		fprintf(txt, "pdf\n");
+		break;
+	case EPS:
+		fprintf(txt, "eps\n");
+		break;
 	}
 	fprintf(txt, "\n");
 	fprintf(txt, "# Save screnshot in B&W or pseudo-grayscales ?\n");
